import{a as o}from"./chunk-OC3NYLOT.js";import"./chunk-UNITEU6O.js";function n(t){return o("button",{...t,class:"px-2 py-1 border-gray-500 border-2 rounded bg-white hover:bg-gray-200 transition-colors"})}function r(t){return o("div",{class:"flex gap-8 py-6",children:[o(n,{onClick:()=>t.count.value-=1,children:"-1"}),o("p",{class:"text-3xl tabular-nums",children:t.count}),o(n,{onClick:()=>t.count.value+=1,children:"+1"})]})}export{r as default};
