import{a as e,b as n}from"./chunk-2E5Q76HC.js";import"./chunk-TY33ZR3E.js";import{a as t}from"./chunk-OC3NYLOT.js";import{d as o}from"./chunk-UNITEU6O.js";function l(){function a(){e.value=null}return t("div",{class:"my-4 p-4 bg-gray-200 rounded-md text-center",children:n.value?t(o,{children:[t("p",{class:"text-gray-700",children:["Logged in as:"," ",t("span",{class:"font-semibold",children:n.value})]}),t("button",{type:"button",onClick:a,class:"btn btn-sm btn-outline mt-2",children:"Logout"})]}):t("p",{class:"text-gray-700",children:"You are not logged in."})})}export{l as default};
