import{a}from"./chunk-UNITEU6O.js";var l=0,v=Array.isArray;function y(o,t,s,p,f,c){t||(t={});var n,r,e=t;if("ref"in e)for(r in e={},t)r=="ref"?n=t[r]:e[r]=t[r];var i={type:o,props:e,key:s,ref:n,__k:null,__:null,__b:0,__e:null,__c:null,constructor:void 0,__v:--l,__i:-1,__u:0,__source:f,__self:c};if(typeof o=="function"&&(n=o.defaultProps))for(r in n)e[r]===void 0&&(e[r]=n[r]);return a.vnode&&a.vnode(i),i}export{y as a};
